@@ -6,8 +6,7 @@ module Text.Parser.Substring
 
 import           Control.Applicative ((<|>))
 import           Data.Attoparsec.Text
-import           Data.Maybe (fromMaybe)
-import           Data.Monoid ((<>), mempty)
+import           Data.Monoid ((<>))
 import           Data.Text (Text)
 import qualified Data.Text.Lazy as Text
 import qualified Data.Text.Lazy.Builder as TextBuilder
@@ -22,17 +21,14 @@ replaceFileOnceWithParser p filePath =
   Text.writeFile filePath =<< replaceOnceWithParser p <$> Text.readFile filePath
 
 
--- TODO: 失敗した場合に元のテキストを返す
 replaceOnceWithParser :: Parser Text -> Text -> Text
-replaceOnceWithParser p =
-  Text.toStrict
-    . TextBuilder.toLazyText
-    . fromMaybe mempty
-    . maybeResult
-    . traceId "fed"
-    . flip feed ""
-    . traceId "parsed"
-    . parse (onceReplacify p)
+replaceOnceWithParser p t =
+  maybe t (Text.toStrict . TextBuilder.toLazyText)
+    $ maybeResult
+    $ traceId "fed"
+    $ flip feed ""
+    $ traceId "parsed"
+    $ parse (onceReplacify p) t
 
 
 onceReplacify :: Parser Text -> Parser Builder
